#documentation start
#=============================================================================
# File data
# creator: Christiane Hassenrck
# acknowledgements: 
# primary authority: Christiane Hassenrck
# other authorities: 
#=============================================================================
# File contents
# Function to allocate correct taxonomic rank to levels of taxonomic path (assigned using SILVA)
# It might be necessary to further curate the taxonomy afterwards (e.g. to account for NoRelative OTUs), but this function should do the majority of the work
# to avoid confusion, rownames of output should be named after OTU names ASAP
# for an example of complete SILVA pipeline in R: see \trunk\clearingHouse\SILVApipe.R
# input: 
# tax - list with length == number of OTUs and in each element an unsorted vector with taxonomic path of that OTU
#  e.g. [[1]]
#       [1] "Eukaryota"         "Archaeplastida"    "Rhodophyceae"      "Florideophycidae"  "Corallinophycidae"
#
#       [[2]]
#       [1] "Eukaryota"        "Archaeplastida"   "Rhodophyceae"     "Florideophycidae" "Nemaliophycidae" 
#       [6] "Audouinella"     
# SILVA - reference table with columns path, node, rank
#  download: http://www.arb-silva.de/fileadmin/silva_databases/release_115/Exports/tax_ranks_ssu_115.csv (SILVA release 115)
#  download: http://www.arb-silva.de/fileadmin/silva_databases/release_119/Exports/taxonomy/tax_slv_ssu_nr_119.txt (SILVA release 119)
#  or (directly usable for below function): \trunk\clearingHouse\SILVA_tax_115_for_R.csv (read with: read.csv("SILVA_tax_115_for_R.csv",sep=",",h=T))
#  e.g. path                                 node         rank
#       Eukaryota                            Eukaryota    domain
#       Eukaryota;Amoebozoa                  Amoebozoa    kingdom
#       Eukaryota;Amoebozoa;Archamoebae      Archamoebae  phylum
# output:
# table with taxonomic path for each OTU, levels corresonding to correct taxonomic rank
#  e.g.    domain      major_clade     superkingdom  kingdom        subkingdom superphylum  phylum            subphylum  class                subclass superorder order suborder family subfamily  genus
#  OTU001 "Eukaryota" "Archaeplastida" NA           "Rhodophyceae"  NA         NA          "Florideophycidae" NA        "Corallinophycidae"   NA       NA         NA    NA       NA     NA         NA      
#  OTU002 "Eukaryota" "Archaeplastida" NA           "Rhodophyceae"  NA         NA          "Florideophycidae" NA        "Nemaliophycidae"     NA       NA         NA    NA       NA     NA        "Audouinella"     
# dependencies:
# \trunk\clearingHouse\SILVA_tax_115_for_R.csv
#=============================================================================
#documentation end

SILVAtaxopath=function(tax,SILVA){
  output=matrix(NA,nrow=length(tax),ncol=length(levels(SILVA$rank))) #create matrix with nrow=number of OTUs and ncol=number of possible taxonomic levels
  colnames(output)=levels(SILVA$rank) #this corresponds to levels(SILVA$rank) sorted in a biologically meaningful order
  
  for(i in 1:length(tax)){ # this loop repeats loop below for each OTU
    for(j in 1:length(levels(SILVA$rank))){ #this loop goes through the taxonomic path of an OTU one level at a time and assigns the name of each level to its correct rank according to SILVA
      if(paste(tax[[i]][1:j],collapse=";") %in% SILVA$path){
        output[i,as.character(SILVA[SILVA$path==paste(tax[[i]][1:j],collapse=";"),"rank"])]=
          as.character(SILVA[SILVA$path==paste(tax[[i]][1:j],collapse=";"),"node"])
      }
    }
  }
  return(output)
}

